@@ -1,4 +1,6 @@
 import numpy as np
+from sentence_transformers import SentenceTransformer
+
 
 def to_bow(data, min_length):
     """Convert index lists to bag of words representation of documents."""
@@ -6,6 +8,16 @@ def to_bow(data, min_length):
             for x in data if np.sum(x[x != np.array(None)]) != 0]
     return np.array(vect)
 
+
+def embed_documents(text_file, sbert_model_to_load):
+    model = SentenceTransformer(sbert_model_to_load)
+
+    with open(text_file, encoding="latin") as filino:
+        train_text = list(map(lambda x: x, filino.readlines()))
+
+    return np.array(model.encode(train_text))
+
+
 class VocabAndTextFromFile:
 
     def __init__(self, file_name):
@@ -35,10 +47,12 @@ class VocabAndTextFromFile:
 
         self.vocab = list(set(concatenate_text.split()))
 
-
         for index, vocab in list(zip(range(0, len(self.vocab)), self.vocab)):
             self.vocab_dict[vocab] = index
 
-        self.index_dd = np.array(list(map(lambda y: np.array(list(map(lambda x : self.dict_to_dump[x], y.split()))), data)))
+        self.index_dd = np.array(list(map(lambda y: np.array(list(map(lambda x : self.vocab_dict[x], y.split()))), data)))
+
+        return self.vocab_dict, self.index_dd
+
 
 
